==> taler-wallet-v1.1.0.tar.gz: taler-wallet-v1.1.0/packages/merchant-backoffice-ui/src/paths/instance/templates/use/index.tsx <==
/*
 This file is part of GNU Taler
 (C) 2021-2024 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

/**
 *
 * @author Sebastian Javier Marchano (sebasjm)
 */

import {
  HttpStatusCode,
  TalerError,
  TalerMerchantApi,
  assertUnreachable,
} from "@gnu-taler/taler-util";
import { useTranslationContext } from "@gnu-taler/web-util/browser";
import { Fragment, VNode, h } from "preact";
import { useState } from "preact/hooks";
import { ErrorLoadingMerchant } from "../../../../components/ErrorLoadingMerchant.js";
import { Loading } from "../../../../components/exception/loading.js";
import { NotificationCard } from "../../../../components/menu/index.js";
import { useTemplateDetails } from "../../../../hooks/templates.js";
import { Notification } from "../../../../utils/types.js";
import { LoginPage } from "../../../login/index.js";
import { NotFoundPageOrAdminCreate } from "../../../notfound/index.js";
import { UsePage } from "./UsePage.js";
import { useSessionContext } from "../../../../context/session.js";

export type Entity = TalerMerchantApi.TransferInformation;
interface Props {
  onBack?: () => void;
  onOrderCreated: (id: string) => void;
  tid: string;
}

export default function TemplateUsePage({
  tid,
  onOrderCreated,
  onBack,
}: Props): VNode {
  const { lib } = useSessionContext();
  const result = useTemplateDetails(tid);
  const [notif, setNotif] = useState<Notification | undefined>(undefined);
  const { i18n } = useTranslationContext();

  if (!result) return <Loading />;
  if (result instanceof TalerError) {
    return <ErrorLoadingMerchant error={result} />;
  }
  if (result.type === "fail") {
    switch (result.case) {
      case HttpStatusCode.NotFound: {
        return <NotFoundPageOrAdminCreate />;
      }
      case HttpStatusCode.Unauthorized: {
        return <LoginPage />;
      }
      default: {
        assertUnreachable(result);
      }
    }
  }

  return (
    <>
      <NotificationCard notification={notif} />
      <UsePage
        template={result.body}
        id={tid}
        onBack={onBack}
        onCreateOrder={(request: TalerMerchantApi.UsingTemplateDetails) => {
          return lib.instance
            .useTemplateCreateOrder(tid, request)
            .then((resp) => {
              if (resp.type === "ok") {
                onOrderCreated(resp.body.order_id);
              } else {
                switch (resp.case) {
                  case HttpStatusCode.UnavailableForLegalReasons: {
                    setNotif({
                      message: i18n.str`Could not create order`,
                      type: "ERROR",
                      description: i18n.str`No exchange would accept a payment because of KYC requirements.`,
                    });
                    return;
                  }
                  case HttpStatusCode.Unauthorized:
                  case HttpStatusCode.NotFound:
                  case HttpStatusCode.Conflict: {
                    setNotif({
                      message: i18n.str`Could not create order`,
                      type: "ERROR",
                      description: resp.detail?.hint,
                    });
                    return;
                  }
                  case HttpStatusCode.Gone: {
                    setNotif({
                      message: i18n.str`Could not create order`,
                      type: "ERROR",
                      description: i18n.str`No more stock for product with ID "${resp.body.product_id}".`,
                    });
                    return;
                  }
                  default: {
                    assertUnreachable(resp);
                  }
                }
              }
            })
            .catch((error) => {
              setNotif({
                message: i18n.str`Could not create order from template`,
                type: "ERROR",
                description:
                  error instanceof Error ? error.message : String(error),
              });
            });
        }}
      />
    </>
  );
}

==> taler-wallet-1.3.1.tar.gz: taler-wallet-v1.3.1/packages/merchant-backoffice-ui/src/paths/instance/templates/use/index.tsx <==
/*
 This file is part of GNU Taler
 (C) 2021-2024 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

/**
 *
 * @author Sebastian Javier Marchano (sebasjm)
 */

import {
  HttpStatusCode,
  TalerError,
  TalerMerchantApi,
  assertUnreachable,
} from "@gnu-taler/taler-util";
import { LocalNotificationBannerBulma, useLocalNotificationBetter, useTranslationContext } from "@gnu-taler/web-util/browser";
import { Fragment, VNode, h } from "preact";
import { ErrorLoadingMerchant } from "../../../../components/ErrorLoadingMerchant.js";
import { Loading } from "../../../../components/exception/loading.js";
import { useSessionContext } from "../../../../context/session.js";
import { useTemplateDetails } from "../../../../hooks/templates.js";
import { LoginPage } from "../../../login/index.js";
import { NotFoundPageOrAdminCreate } from "../../../notfound/index.js";
import { UsePage } from "./UsePage.js";

export type Entity = TalerMerchantApi.TransferInformation;
interface Props {
  onBack?: () => void;
  onOrderCreated: (id: string) => void;
  tid: string;
}

export default function TemplateUsePage({
  tid,
  onOrderCreated,
  onBack,
}: Props): VNode {
  const result = useTemplateDetails(tid);

  if (!result) return <Loading />;
  if (result instanceof TalerError) {
    return <ErrorLoadingMerchant error={result} />;
  }
  if (result.type === "fail") {
    switch (result.case) {
      case HttpStatusCode.NotFound: {
        return <NotFoundPageOrAdminCreate />;
      }
      case HttpStatusCode.Unauthorized: {
        return <LoginPage />;
      }
      default: {
        assertUnreachable(result);
      }
    }
  }

  return (
    <>
      <UsePage
        template={result.body}
        id={tid}
        onBack={onBack}
        onOrderCreated={onOrderCreated}
      />
    </>
  );
}
